@@ -25,6 +25,7 @@
 #include "allocate.h"
 #include "gettext.h"
 #include "widgets.h"
+#include "show_info.h"
 #include "commands.h"
 #include "make_settings_entries.h"
 #include "make_settings_combos.h"
@@ -66,7 +67,8 @@ void show_domain_settings_window(struct w *widgets)
 
     /* Set window information */
     info = g_strdup_printf(_("GBINDADMIN %s domain settings"), VERSION);
-    gtk_window_set_title(GTK_WINDOW(widgets->domain_settings_window), info);
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_window_set_title(GTK_WINDOW(widgets->domain_settings_window), utf8);
     g_free(info);
 
     g_signal_connect(GTK_WINDOW(widgets->domain_settings_window), "delete_event", 
@@ -77,7 +79,11 @@ void show_domain_settings_window(struct w *widgets)
 
 
     tooltips = gtk_tooltips_new();
-    frame = gtk_frame_new("Domain settings:");
+
+    info = g_strdup_printf(_("Domain settings:"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    frame = gtk_frame_new(utf8);
+    g_free(info);
 
     /* A table with 8 settings and 2 columns */
     table = gtk_table_new(10, 2, FALSE);
@@ -90,27 +96,49 @@ void show_domain_settings_window(struct w *widgets)
 
 
     /* Domain name */
-    widgets->domain_settings_entry[0] = make_entry_with_label(GTK_TABLE(table), _(" Domain name: "),    0,1,2,3,350);
+    info = g_strdup_printf(_(" Domain name: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[0] = make_entry_with_label(GTK_TABLE(table), utf8,    0,1,2,3,350);
+    g_free(info);
+    
     utf8 = g_locale_to_utf8(global_domain_name, strlen(global_domain_name), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->domain_settings_entry[0]), utf8);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[0], _("some.domain.org"), NULL);
+
+    info = g_strdup_printf(_("some.domain.org"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[0], utf8, NULL);
+    g_free(info);
 
     /* Address range */
-    widgets->domain_settings_entry[1] = make_entry_with_label(GTK_TABLE(table), _(" Address range: "),    0,1,3,4,350);
+    info = g_strdup_printf(_(" Address range: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[1] = make_entry_with_label(GTK_TABLE(table), utf8,    0,1,3,4,350);
+    g_free(info);
+
     utf8 = g_locale_to_utf8(global_domain_address, strlen(global_domain_address), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->domain_settings_entry[1]), utf8);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[1], _("192.168.0.0-254"), NULL);
+
+    info = g_strdup_printf(_("192.168.0.1-254"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[1], utf8, NULL);
+    g_free(info);
 
     /* Domain type combo */
-    widgets->domain_settings_combo[0] = make_combo_with_label(GTK_TABLE(table), _(" Domain type: "),    0,1,4,5,350);
-    tmp = allocate(1024);
-    snprintf(tmp, 1000, "%s", _("master"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    info = g_strdup_printf(_(" Domain type: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_combo[0] = make_combo_with_label(GTK_TABLE(table), utf8,    0,1,4,5,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("master"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[0]), utf8);
-    snprintf(tmp, 1000, "%s", _("slave"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    g_free(info);
+
+    info = g_strdup_printf(_("slave"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[0]), utf8);
-    free(tmp);
+    g_free(info);
+
 
     if( strstr(global_domain_type, "master") )
       gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->domain_settings_combo[0]), 0);
@@ -125,24 +153,40 @@ void show_domain_settings_window(struct w *widgets)
 
 
     /* Administrator email */
-    widgets->domain_settings_entry[2] = make_entry_with_label(GTK_TABLE(table), _(" Administrator email: "),    0,1,5,6,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[2], _("hostmaster@some.domain.org"), NULL);
+    info = g_strdup_printf(_(" Administrator email: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[2] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,5,6,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("hostmaster@yourdomain.org"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[2], utf8, NULL);
+    g_free(info);
 
     /* Domain serial */
-    widgets->domain_settings_entry[3] = make_entry_with_label(GTK_TABLE(table), _(" Domain serial: "),    0,1,6,7,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[3], _("Year+Month+Day+A 2-digit serial, IE: 2006040255"), NULL);
+    info = g_strdup_printf(_(" Domain serial: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[3] = make_entry_with_label(GTK_TABLE(table), utf8,    0,1,6,7,350);
+    g_free(info);
 
+    info = g_strdup_printf(_("Year+Month+Day+A 2-digit serial, IE: 2006040255"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[3], utf8, NULL);
+    g_free(info);
 
     fwd_zone_path = g_strdup_printf("%s/etc/sites/%s/forward.zone", CHROOT_PATH_BUF, global_domain_name);
 
 
+    if( utf8!=NULL )
+      g_free(utf8);
+
+
     /* Insert widget values from the selected sites forward zone */
     if((fp=fopen(fwd_zone_path, "r"))==NULL)
     {
-	printf("Error: could not find the sites forward zone here: %s\n", fwd_zone_path);
-
-	if( utf8!=NULL )
-	  g_free(utf8);
+	info = g_strdup_printf(_("Error: could not find the sites forward zone here:\n%s\n"), fwd_zone_path);
+	show_info(info);
+	g_free(info);
 
 	g_free(fwd_zone_path);
 	return;
@@ -190,72 +234,121 @@ void show_domain_settings_window(struct w *widgets)
 
 
     /* allow-update */
-    widgets->domain_settings_entry[4] = make_entry_with_label(GTK_TABLE(table), _(" Allow update: "),    0,1,7,8,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[4], _("Hosts allowed to submit dynamic DNS updates (DDNS) delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"), NULL);
+    info = g_strdup_printf(_(" Allow update: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[4] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,7,8,350);
+    g_free(info);
+    
+    info = g_strdup_printf(_("Hosts allowed to submit dynamic DNS updates (DDNS) delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[4], utf8, NULL);
+    g_free(info);
 
     /* allow-transfer */
-    widgets->domain_settings_entry[5] = make_entry_with_label(GTK_TABLE(table), _(" Allow transfers: "),    0,1,8,9,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[5], _("Hosts allowed to make zone transfers (copy the zone information) delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"), NULL);
+    info = g_strdup_printf(_(" Allow transfer: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[5] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,8,9,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("Hosts that are allowed to make zone transfers (copy the entire zone) delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[5], utf8, NULL);
+    g_free(info);
 
     /* allow-query */
-    widgets->domain_settings_entry[6] = make_entry_with_label(GTK_TABLE(table), _(" Allow query: "),    0,1,9,10,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[6], _("Hosts allowed to query this DNS, delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"), NULL);
+    info = g_strdup_printf(_(" Allow query: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[6] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,9,10,350);
+    g_free(info);
 
+    info = g_strdup_printf(_("Hosts allowed to query this DNS, delimited with a \";\" IE: 127.0.0.1; 192.168.0.0/24; any; or none;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[6], utf8, NULL);
+    g_free(info);
 
     /* Notify combo */
-    widgets->domain_settings_combo[2] = make_combo_with_label(GTK_TABLE(table), _(" Send notifications: "),    0,1,10,11,350);
-    tmp = allocate(1024);
+    info = g_strdup_printf(_(" Send notifications: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_combo[2] = make_combo_with_label(GTK_TABLE(table), utf8, 0,1,10,11,350);
+    g_free(info);
 
-    snprintf(tmp, 1000, "%s", _("yes"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    info = g_strdup_printf(_("yes"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[2]), utf8);
+    g_free(info);
     
-    snprintf(tmp, 1000, "%s", _("no"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    info = g_strdup_printf(_("no"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[2]), utf8);
+    g_free(info);
 
-    snprintf(tmp, 1000, "%s", _("explicit"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    info = g_strdup_printf(_("explicit"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[2]), utf8);
-
-    free(tmp);
+    g_free(info);
 
 
     /* Also-notify (for masters only) */
-    widgets->domain_settings_entry[7] = make_entry_with_label(GTK_TABLE(table), _(" Also notify: "),    0,1,11,12,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[7], _("Servers that should recieve zone update notifications delimited with a \";\" IE: 127.0.0.1; 192.168.0.100;"), NULL);
+    info = g_strdup_printf(_(" Also notify: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[7] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,11,12,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("Servers that should recieve zone update notifications delimited with a \";\" IE: 127.0.0.1; 192.168.0.100;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[7], utf8, NULL);
+    g_free(info);
 
     /* Allow-notify (for slaves only) */
-    widgets->domain_settings_entry[8] = make_entry_with_label(GTK_TABLE(table), _(" Allow notify: "),    0,1,12,13,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[8], _("Servers allowed to notify this server for zone updates delimited with a \";\" IE: 127.0.0.1; 192.168.0.100; any; or none;"), NULL);
+    info = g_strdup_printf(_(" Allow notify: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[8] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,12,13,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("Servers allowed to notify this server for zone updates delimited with a \";\" IE: 127.0.0.1; 192.168.0.100; any; or none;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[8], utf8, NULL);
+    g_free(info);
 
     /* Statistics combo */
-    widgets->domain_settings_combo[1] = make_combo_with_label(GTK_TABLE(table), _(" Domain statistics: "),    0,1,13,14,350);
-    tmp = allocate(1024);
-    snprintf(tmp, 1000, "%s", _("yes"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    info = g_strdup_printf(_(" Domain statistics: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_combo[1] = make_combo_with_label(GTK_TABLE(table), utf8, 0,1,13,14,350);
+    g_free(info);
+
+    info = g_strdup_printf(_("yes"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[1]), utf8);
-    snprintf(tmp, 1000, "%s", _("no"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    g_free(info);
+
+    info = g_strdup_printf(_("no"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->domain_settings_combo[1]), utf8);
-    free(tmp);
+    g_free(info);
 
     /* masters (for slave domains only) */
-    widgets->domain_settings_entry[9] = make_entry_with_label(GTK_TABLE(table), _(" Master domains: "),    0,1,14,15,350);
-    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[9], _("IP-addresses of the master domains delimited with a \";\" IE: 127.0.0.1; 192.168.0.100; none;"), NULL);
+    info = g_strdup_printf(_(" Master domains: "));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    widgets->domain_settings_entry[9] = make_entry_with_label(GTK_TABLE(table), utf8, 0,1,14,15,350);
+    g_free(info);
 
+    info = g_strdup_printf(_("IP-addresses of the master domains delimited with a \";\" IE: 127.0.0.1; 192.168.0.100; none;"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->domain_settings_entry[9], utf8, NULL);
+    g_free(info);
+
+    if( utf8!=NULL )
+      g_free(utf8);
 
     /* Insert widget values from named.conf */
     named_conf = g_strdup_printf("%s/etc/named.conf", CHROOT_PATH_BUF);
     if((fp=fopen(named_conf, "r"))==NULL)
     {
-	printf("Error: could not find named.conf here:\n%s\n", named_conf);
-
-	if( utf8!=NULL )
-	  g_free(utf8);
+	info = g_strdup_printf(_("Error: could not open named.conf here:\n%s\n"), named_conf);
+	show_info(info);
+	g_free(info);
 
 	g_free(named_conf);
-
 	return;
     }
     fseek(fp, 0, SEEK_END);
