@@ -1,5 +1,5 @@
 
-/* Several defines for different OSes. */
+/* Several defines and includes for different OSes. */
 
 #include "../config.h"
 
@@ -34,7 +34,7 @@
   #define ADDUSER "useradd"
   #define ADDGROUP "groupadd"
   #define NULLDEVICE "/dev/null"
-  #include "osx_functions.c"
+//  #include "osx_functions.h"
 #elif defined USE_AIX
   #define NOBODY "nobody"
   #define ADDUSER "useradd"
